Added /support/savetransfer to .gitignore.
[rsync/rsync.git] / flist.c
diff --git a/flist.c b/flist.c
index 41035ff..d11437f 100644 (file)
--- a/flist.c
+++ b/flist.c
@@ -696,7 +696,7 @@ static struct file_struct *recv_file_entry(struct file_list *flist,
 
                if (iconvbufs(ic_recv, &inbuf, &outbuf, 0) < 0) {
                        io_error |= IOERR_GENERAL;
-                       rprintf(FERROR_XFER,
+                       rprintf(FERROR_UTF8,
                            "[%s] cannot convert filename: %s (%s)\n",
                            who_am_i(), lastname, strerror(errno));
                        outbuf.len = 0;
@@ -839,10 +839,10 @@ static struct file_struct *recv_file_entry(struct file_list *flist,
                }
 #ifdef ICONV_OPTION
                /* We don't know how much extra room we need to convert
* the as-yet-unread symlink name when converting it,
* so let's hope that a double-size buffer is plenty. */
                if (sender_symlink_iconv)
-                       linkname_len = linkname_len * 2 + 1;
+                       linkname_len *= 2;
 #endif
                if (munge_symlinks)
                        linkname_len += SYMLINK_PREFIX_LEN;
@@ -989,9 +989,9 @@ static struct file_struct *recv_file_entry(struct file_list *flist,
                                xbuf outbuf, inbuf;
 
                                alloc_len = linkname_len;
-                               linkname_len /= 2; /* (linkname_len-1) / 2 for odd values. */
+                               linkname_len /= 2;
 
/* Read the symlink name into the end of our double-sized
                                 * buffer and then convert it into the right spot. */
                                INIT_XBUF(inbuf, bp + alloc_len - linkname_len,
                                          linkname_len - 1, (size_t)-1);
@@ -1001,7 +1001,7 @@ static struct file_struct *recv_file_entry(struct file_list *flist,
                                if (iconvbufs(ic_recv, &inbuf, &outbuf, 0) < 0) {
                                        io_error |= IOERR_GENERAL;
                                        rprintf(FERROR_XFER,
-                                           "[%s] cannot convert symlink name for: %s (%s)\n",
+                                           "[%s] cannot convert symlink data for: %s (%s)\n",
                                            who_am_i(), full_fname(thisname), strerror(errno));
                                        bp = (char*)file->basename;
                                        *bp++ = '\0';
@@ -1149,7 +1149,7 @@ struct file_struct *make_file(const char *fname, struct file_list *flist,
                        }
                } else {
                        io_error |= IOERR_GENERAL;
-                       rsyserr(FERROR_XFER, save_errno, "readlink %s failed",
+                       rsyserr(FERROR_XFER, save_errno, "readlink_stat(%s) failed",
                                full_fname(thisname));
                }
                return NULL;
@@ -1430,7 +1430,7 @@ static struct file_struct *send_file_name(int f, struct file_list *flist,
                                        io_error |= IOERR_GENERAL;
                                        f_name(file, fbuf);
                                        rprintf(FERROR_XFER,
-                                           "[%s] cannot convert symlink name for: %s (%s)\n",
+                                           "[%s] cannot convert symlink data for: %s (%s)\n",
                                            who_am_i(), full_fname(fbuf), strerror(errno));
                                        return NULL;
                                }
@@ -839,10 +839,10 @@ static struct file_struct *recv_file_entry(struct file_list *flist,
 #ifdef ICONV_OPTION
                /* We don't know how much extra room we need to convert
-                * the as-yet-unread symlink name when converting it,
-                * so let's hope that a double-size buffer is plenty. */
+                * the as-yet-unread symlink data, so let's hope that a
+                * double-size buffer is plenty. */
                if (sender_symlink_iconv)
@@ -989,9 +989,9 @@ static struct file_struct *recv_file_entry(struct file_list *flist,
 
-                               /* Read the symlink name into the end of our double-sized
+                               /* Read the symlink data into the end of our double-sized
                                 * buffer and then convert it into the right spot. */
                                INIT_XBUF(inbuf, bp + alloc_len - linkname_len,